@@ -442,6 +442,27 @@ def get_image_eye_mask (image_shape, image_landmarks):
 
     return hull_mask
 
+def get_image_mouth_mask (image_shape, image_landmarks):
+    if len(image_landmarks) != 68:
+        raise Exception('get_image_eye_mask works only with 68 landmarks')
+
+    h,w,c = image_shape
+
+    hull_mask = np.zeros( (h,w,1),dtype=np.float32)
+
+    image_landmarks = image_landmarks.astype(np.int)
+
+    cv2.fillConvexPoly( hull_mask, cv2.convexHull( image_landmarks[60:]), (1,) )
+
+    dilate = h // 32
+    hull_mask = cv2.dilate(hull_mask, cv2.getStructuringElement(cv2.MORPH_ELLIPSE,(dilate,dilate)), iterations = 1 )
+
+    blur = h // 16
+    blur = blur + (1-blur % 2)
+    hull_mask = cv2.GaussianBlur(hull_mask, (blur, blur) , 0)
+    hull_mask = hull_mask[...,None]
+
+    return hull_mask
 
 def alpha_to_color (img_alpha, color):
     if len(img_alpha.shape) == 2:
@@ -453,7 +474,6 @@ def alpha_to_color (img_alpha, color):
     return result * img_alpha
 
 
-
 def get_cmask (image_shape, lmrks, eyebrows_expand_mod=1.0):
     h,w,c = image_shape
 
